@@ -13,7 +13,11 @@ class KestrelException(Exception):
 
     def __init__(self, error, suggestion=""):
         self.error = error if error[-1] == "." else error + "."
-        self.suggestion = suggestion if suggestion[-1] == "." else suggestion + "."
+        self.suggestion = (
+            suggestion
+            if (not suggestion or suggestion[-1] == ".")
+            else suggestion + "."
+        )
 
     def __str__(self):
         return f"[ERROR] {self.__class__.__name__}: {self.error} {self.suggestion}"
@@ -232,7 +236,7 @@ class ConflictingAnalyticsInterfaceScheme(KestrelException):
 
 class InvalidAnalyticsInput(KestrelException):
     def __init__(self, type_received, types_expected):
-        typelist = ", ".join(types_expected)
+        typelist = ", ".join([f'"{t}"' for t in types_expected])
         super().__init__(
-            f'received unsupported type "{type_received}"; expected one of "{typelist}"'
+            f'received unsupported type "{type_received}"; expected one of {typelist}'
         )
